@@ -125,14 +125,14 @@ class Component:
             raise ValueError(f'unknown event {event}')
         self._event_handlers[event].append(handler)
 
-    async def _dispatch_event(self, event: str):
+    async def _dispatch_event(self, event: str, **kwargs):
         assert event in self.EVENTS, "no such event to dispatch"
         for handler in self._event_handlers[event]:
             try:
                 if asyncio.iscoroutinefunction(handler):
-                    await handler()
+                    await handler(**kwargs)
                 else:
-                    handler()
+                    handler(**kwargs)
             except Exception as e:
                 warnings.warn(f'event handler failed with exception: {e.__class__.__name__}({e})', RuntimeWarning)
 
